@@ -7,7 +7,7 @@ use Carp;
 use Woothee::Util qw/update_map update_category update_version update_os/;
 use Woothee::DataSet qw/dataset/;
 
-our $VERSION = "0.3.7";
+our $VERSION = "0.3.8";
 
 sub challenge_msie {
     my ($ua,$result) = @_;
@@ -17,7 +17,7 @@ sub challenge_msie {
     my $version;
     if ($ua =~ m{MSIE ([.0-9]+);}o) {
         $version = $1;
-    } elsif ($ua =~ m{Trident/([.0-9]+); rv ([.0-9]+)}o) {
+    } elsif ($ua =~ m{Trident/([.0-9]+); rv:([.0-9]+)}o) {
         $version = $2;
     } else {
         $version = Woothee::DataSet->const('VALUE_UNKNOWN');
